@@ -11,11 +11,10 @@ from bigeye_sdk.bigconfig_validation.yaml_validation_error_messages import SRC_N
     METRIC_APPLICATION_ERROR
 from bigeye_sdk.client.datawatch_client import DatawatchClient
 from bigeye_sdk.exceptions.exceptions import FileLoadException, BigConfigValidationException, NoSourcesFoundException
-from bigeye_sdk.functions.bigconfig_functions import explode_fq_column_selectors
 from bigeye_sdk.functions.metric_functions import _is_table_level_metric
 from bigeye_sdk.functions.search_and_match_functions import wildcard_search
 from bigeye_sdk.generated.com.bigeye.models.generated import Source, CohortDefinition, \
-    MetricSuite, CohortAndMetricDefinition, CatalogEntityType, MetricDefinition
+    MetricSuite, CohortAndMetricDefinition, CatalogEntityType, MetricDefinition, FieldType
 from bigeye_sdk.model.big_config import BigConfig, RowCreationTimes, TagDeployment, TableDeployment
 from bigeye_sdk.model.protobuf_enum_facade import SimplePredefinedMetricName
 from bigeye_sdk.model.protobuf_message_facade import SimpleSLA, SimpleMetricDefinition
@@ -131,11 +130,7 @@ class MetricSuiteController:
         r: Dict[int, List[CohortDefinition]] = {}
 
         for cs in row_creation_times.column_selectors:
-            split: List[str] = explode_fq_column_selectors(cs.name)
-            source_pattern = split[0]
-            schema_pattern = split[1]
-            table_pattern = split[2]
-            column_pattern = split[3]
+            source_pattern, schema_pattern, table_pattern, column_pattern = cs.explode_name_to_cohort_patterns()
 
             matching_source_ids = [source.id
                                    for source_name, source in self.sources_by_name_ix.items()
@@ -151,8 +146,11 @@ class MetricSuiteController:
                     error_message=SRC_NOT_EXISTS_FOR_DEPLOYMENT_ERRMSG.format(fq_name=cs))
 
             for id in matching_source_ids:
-                cd = CohortDefinition(schema_name_pattern=schema_pattern, table_name_pattern=table_pattern,
+                cd = CohortDefinition(schema_name_pattern=schema_pattern,
+                                      table_name_pattern=table_pattern,
                                       column_name_pattern=column_pattern,
+                                      column_type=cs.type.to_datawatch_object() if cs.type
+                                                    else FieldType.FIELD_TYPE_UNSPECIFIED,
                                       entity_type=CatalogEntityType.CATALOG_ENTITY_TYPE_FIELD)
                 if id in r.keys():
                     r[id].append(cd)
@@ -223,18 +221,13 @@ class MetricSuiteController:
                 column_metrics.append((m, mdwo))
 
         for cs in tag_deployment.column_selectors:
-            cse = explode_fq_column_selectors(cs.name)
-            source_pattern = cse[0]
-            schema_pattern = cse[1]
-            table_pattern = cse[2]
-            column_pattern = cse[3]
+            source_pattern, schema_pattern, table_pattern, column_pattern = cs.explode_name_to_cohort_patterns()
 
             matching_source_ids = [source.id
                                    for source_name, source in self.sources_by_name_ix.items()
                                    if source_name in wildcard_search(search_string=source_pattern,
                                                                      content=[source_name])
                                    ]
-
             if not matching_source_ids:
                 "registering validation errors when the source was not matched."
                 tag_deployment.register_validation_error(
@@ -243,8 +236,11 @@ class MetricSuiteController:
 
             if column_metrics:
                 """Only append cohorts if metrics actually exist."""
-                columns_cohort = CohortDefinition(schema_name_pattern=schema_pattern, table_name_pattern=table_pattern,
+                columns_cohort = CohortDefinition(schema_name_pattern=schema_pattern,
+                                                  table_name_pattern=table_pattern,
                                                   column_name_pattern=column_pattern,
+                                                  column_type=cs.type.to_datawatch_object() if cs.type
+                                                    else FieldType.FIELD_TYPE_UNSPECIFIED,
                                                   entity_type=CatalogEntityType.CATALOG_ENTITY_TYPE_FIELD)
                 for sid in matching_source_ids:
                     """Tag deployments support source patterns.  Each source id becomes a key in the returned dictionary 
@@ -268,6 +264,8 @@ class MetricSuiteController:
 
                 table_cohort = CohortDefinition(schema_name_pattern=schema_pattern, table_name_pattern=table_pattern,
                                                 column_name_pattern=column_pattern,
+                                                column_type=cs.type.to_datawatch_object() if cs.type
+                                                    else FieldType.FIELD_TYPE_UNSPECIFIED,
                                                 entity_type=CatalogEntityType.CATALOG_ENTITY_TYPE_DATASET)
 
                 for sid in matching_source_ids:
